@@ -62,7 +62,7 @@
 #define KDECORATIONS3_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS3_NO_DEPRECATED
-#  define KDECORATIONS3_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60400
+#  define KDECORATIONS3_DISABLE_DEPRECATED_BEFORE_AND_AT 0x6045a
 #endif
 #ifdef KDECORATIONS3_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS3_DEPRECATED_WARNINGS_SINCE 0
@@ -72,7 +72,7 @@
 #  ifdef KDECORATIONS3_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS3_DEPRECATED_WARNINGS_SINCE KDECORATIONS3_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS3_DEPRECATED_WARNINGS_SINCE 0x60400
+#    define KDECORATIONS3_DEPRECATED_WARNINGS_SINCE 0x6045a
 #  endif
 #endif
 
